<!DOCTYPE html>
<!--[if lt IE 7]> <html class="no-js lt-ie9 lt-ie8 lt-ie7"> <![endif]-->
<!--[if IE 7]>    <html class="no-js lt-ie9 lt-ie8"> <![endif]-->
<!--[if IE 8]>    <html class="no-js lt-ie9"> <![endif]-->
<!--[if gt IE 8]><!--> <html class="no-js"> <!--<![endif]-->
<html {% block htmlprop %}lang="en"{% endblock htmlprop %}>

{% load compress %}
{% load staticfiles %}
{% load i18n %}

<head>
    <meta charset="utf-8">
    <title>{% block title %}{% endblock title %} &#8212; {% trans 'My Project' %}</title>
    <meta name="description" content="{% block description %}{% trans 'My Project' %}{% endblock description %}" />
    <meta name="keywords" content="{% block keywords %}my, project{% endblock keywords %}" />

    {% block metas_seo %}{% endblock metas_seo %}

    <meta name="viewport" content="width=device-width" />

    <!--[if lt IE 9]>
    <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->

    <link rel="shortcut icon" href="{% static 'img/favicon.ico' %}" />
    {% compress css %}
    <link rel="stylesheet" href="{% static 'vendors/font-awesome/css/font-awesome.min.css' %}">
    <link rel="stylesheet" href="{% static 'vendors/mediaelement/build/mediaelementplayer.min.css' %}">
    <link rel="stylesheet" href="{% static 'vendors/jquery-colorbox/example3/colorbox.css' %}">
    <link rel="stylesheet" href="{% static 'vendors/dropzone/downloads/css/dropzone.css' %}">
    <link rel="stylesheet" href="{% static 'vendors/select2/select2.css' %}">
    <link rel="stylesheet" href="{% static 'vendors/select2/select2-bootstrap.css' %}">
    <link rel="stylesheet" href="{% static 'less/custom.less' %}" type="text/less" >
    {% endcompress %}
    {% block css %}
    {% endblock css %}
</head>

<body class="{% block body_class %}base{% endblock body_class %}">


    <div class="navbar navbar-inverse navbar-fixed-top" role="navigation">
      <div class="container">
        <div class="navbar-header">
          <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target=".navbar-collapse">
            <span class="sr-only">{% trans 'Toggle navigation' %}</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a class="navbar-brand" href="{% url 'index' %}">{% trans 'My Project' %}</a>
        </div>
        <div class="collapse navbar-collapse">
          <ul class="nav navbar-nav">
            <li class="active"><a href="">{% trans 'Home' %}</a></li>
            <li><a href="">{% trans 'Blog' %}</a></li>
            <li><a href="">{% trans 'Gallery' %}</a></li>
          </ul>
          <ul class="nav navbar-nav navbar-right">
            <li class="dropdown">
              <a href="#" class="dropdown-toggle" data-toggle="dropdown"><i class="fa fa-user"></i> {% trans 'User' %} <span class="caret"></span></a>
              <ul class="dropdown-menu" role="menu">
                <li><a href=""><i class="fa fa-home"></i> {% trans 'Home' %}</a></li>
                <li class="divider"></li>
                <li><a href=""><i class="fa fa-power-off"></i> {% trans 'Logout' %}</a></li>
              </ul>
            </li>
          </ul>
        </div><!--/.nav-collapse -->
      </div>
    </div>

    <div class="container">

      <section id="content" class="{% block content_class %}{% endblock content_class %}">

        {% block notification %}
          <section id="notification">
            <a name="notification"></a>
            {% block notification_extra %}
            {% endblock notification_extra %}
          </section>
        {% endblock notification %}

        <div class="leftcol">
            <div class="well">
            {% block leftcol %}
              <ul>
                <li class="nav-header">{% trans 'options' %}</li>
                <li class="active"><a href="">{% trans 'home' %}</a></li>
                <li><a href="">{% trans 'blog' %}</a></li>
                <li><a href="">{% trans 'gallery' %}</a></li>
              </ul>
            {% endblock leftcol %}
            </div>
        </div>

        <div class="maincol">
            <div class="content">
                <ul class="breadcrumb">
                    {% block breadcrumbs %}
                    <li><a href="">{% trans 'home' %}</a></li>
                    {% endblock breadcrumbs %}
                </ul>

                {% block content %}
                    <p>Fetal stemcells, aren't those controversial? Oh, how I
                    wish I could believe or understand that! There's only one
                    reasonable course of action now: kill Flexo! Kif, I have
                    mated with a woman. Inform the men.</p>
                    <p>Bender, this is Fry's decision&hellip; and he made it
                    wrong. So it's time for us to interfere in his life. Fry!
                    Quit doing the right thing, you jerk! Oh right. I forgot
                    about the battle. You're going back for the Countess,
                    aren't you?</p>
                    <p>Shut up and get to the point! Morbo will now introduce
                    tonight's candidates&hellip; PUNY HUMAN NUMBER ONE, PUNY
                    HUMAN NUMBER TWO, and Morbo's good friend, Richard Nixon.
                    Now, now. Perfectly symmetrical violence never solved
                    anything.</p>
                {% endblock content %}
            </div>
        </div>

      </section>
    </div>

    <footer id="footer">
        <div class="container">
            <p>{% trans 'My Project' %}</p>
        </div>
    </footer>

    {% compress js %}
    <script type="text/javascript" src="{% static 'vendors/jquery/jquery.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/transition.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/alert.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/modal.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/dropdown.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/scrollspy.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/tab.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/tooltip.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/popover.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/button.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/collapse.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/carousel.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/bootstrap/js/affix.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/jquery-colorbox/jquery.colorbox.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/mediaelement/build/mediaelement-and-player.min.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/dropzone/downloads/dropzone.min.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/select2/select2.min.js' %}"></script>
    <script type="text/javascript" src="{% static 'vendors/jquery-cookie/jquery.cookie.js' %}"></script>
    <script type="text/javascript" src="{% static 'js/custom.js' %}"></script>
    {% endcompress %}
    {% block js %}
    {% endblock js %}

    {% block javascript %}
    {% endblock javascript %}

</body>
</html>
