{% load i18n %}

{% comment %}
{% for folder in folders %}
      <li>
        <a href="{# url rgallery-folder folder.slug #}">
            <i class="fa fa-folder-open"></i>
            <div>{# folder.title #}</div>
        </a>
      </li>
{% endfor %}
{% endcomment %}
